function M=matprojisoplan(type,param)
%MATPROJISOPLAN Matrice projective d'une isomtrie du plan
%   Renvoie la matrice projective correspondant au type demand :
%   0, 'trans' ou 'translation' : matrice de *translation*
%   1, 'glis' ou 'glissement' : matrice de *glissement*
%   2, 'rot' ou  'rotation' : matrice de *rotation*
%
%   Les vecteurs se passent comme vecteurs colonnes, les points comme
%   vecteurs ligne, et les angles en radian, dans le tableau param.
%
%   T = MATPROJISOPLAN(0, {VECTEUR}) est la translation de vecteur donn.
%
%   G = MATPROJISOPLAN(1, {POINT, VECTEUR}) est le glissement de miroir
%   passant par le point donn, et dirig par le vecteur donn.
%
%   R = MATPROJISOPLAN(2, {CENTRE, ANGLE}) est la rotation de centre et
%   d'angle fournis
%
%   Example:
%   matprojisoplan('glis',{[1,0],[2;-1]})
%
%   See also MATPROJTRANS, MATPROJGLIS, MATPROJROT, NATURE.

%   Copyright 2006 Laurent Couvidou

switch type
    
    case {0, 'trans', 'translation'}
        vecteur = verif2d('vecteur',param{1});
        M=matprojtrans(vecteur);

    case {1, 'glis', 'glissement'}
        point = verif2d('point',param{1});
        vecteur = verif2d('vecteur',param{2});
        M=matprojglis(point, vecteur);

    case {2, 'rot', 'rotation'}
        centre = verif2d('point',param{1});
        angle = verif2d('angle',param{2});
        M=matprojrot(centre, angle);
        
    otherwise
        if isnumeric(type)
            error(['Le type ' num2str(type) ' n existe pas'])
        else
            error(['Le type ' type ' n existe pas'])

end
end
