function [n,param]=nature(M)
%NATURE Cherche la nature d'un matrice suppose d'isomtrie du plan
%   N = NATURE(M) Renvoie la nature N de l'isomtrie correspondant  M sous
%   forme de chane :
%   'translation' : matrice de *translation*
%   'glissement' : matrice de *glissement*
%   'rotation' : matrice de *rotation*
%
%   [N,PARAM] = NATURE(M) Renvoie la nature et les paramtres de
%   l'isomtrie transformation, sous forme d'un tableau. On obtient donc
%   - PARAM = {VECTEUR} pour une translation
%   - PARAM = {CENTRE,ANGLE} pour une rotation
%   - PARAM = {POINT,VECTEUR} pour un glissement
%   Ces paramtres sont compatibles avec MATPROJISOPLAN.
%
%   See also MATPROJISOPLAN.

%   Copyright 2006 Laurent Couvidou

d = det(M);

% On utilise le Thorme 18 du cours sur les isomtrie affines du plan
% On prends en compte l'erreur numrique sur le calcul du dterminant
epsilon = 0.0000000001; % e-10
if (abs(d) <= 1 + epsilon) && (abs(d) >= 1 - epsilon)

    if d > 0 % on considre d = 1;

        % C'est une isomtrie directe
        
        if M(1:2,1:2) == eye(2) % translation
            n = 'translation';
            param{1} = [M(1,3);M(2,3)];
        else % rotation
            n = 'rotation';
            % Le centre de rotation est donn par le vecteur propre en
            % 3eme colonne
            % Nb : il faut diviser par le facteur de proportion (troisime
            % ligne des vecteurs propres) pour obtenir les bonnes valeurs
            [vect,val] = eig(M);
            param{1} = [vect(1,3)/vect(3,3),vect(2,3)/vect(3,3)];
            % L'angle se calcule simplement avec les cosinus et sinus
            % prsents dans la partie linaire de la matrice
            param{2} = atan2(M(2,1),M(1,1));
       end
        
        
    else % on considre d = -1

        % C'est une isomtrie indirecte
        
        n = 'glissement';
        % On pourrait rcuprer un vecteur directeur de l'axe par rapport
        % aux abcisses via le vecteur propre associ  la valeur 1
        % [vect,val] = eig(M)
        % dir = [vect(1,n)/vect(3,n),vect(2,n)/vect(3,n)];
        % etc.
        % Cependant on n'a pas besoin de ce vecteur directeur, qui n'est
        % pas considr comme paramtre (redondance avec le vecteur trans-
        % lation). On se contente donc de prendre le milieu d'un point et
        % de son image (point sur l'axe), et de lui appliquer le glissement
        % (la diffrence des deux donne le vecteur translation) ; mthode
        % moins lourde en calculs
        o = [0,0,1]; % origine
        m = (o+(M*o')')/2; % point homogne milieu entre O et son image
        v = ((M*m')'-m)'; % vecteur translation : l'image de m moins m
        % Retour : pas de coordonnes homognes
        param{1} = m(1,1:2);
        param{2} = v(1:2,1);
    end

else
    % La matrice ne ressemble dfinitivement pas  une isomtrie
    % (mme si le test n'est pas complet : un dterminant  1 ou -1 ne
    % prouve rien).
    error([mat2str(M) 'n est pas une matrice d isomtrie'])
    
end

end